"""Code to classify the source of a signal using the given features,
using SGD classifier."""

# Figure out way to get rid of sklearn deprecation warning

import pandas as pd
import numpy as np
import sklearn as sk
import time
import json
import pickle


def sgd():

    print("Reading in dataset and preparing...")
    s = pd.read_csv('./data/processed/stars_proc.csv',
                    low_memory=False)

    # Drop Unnamed: 0, because it doesn't seem to drop for some reason
    s = s.drop(['Unnamed: 0'], axis=1)

    print("Splitting into labels and features...")
    y = s['Source']
    x = s[['Frequency(MHz)', 'Signal_to_noise_ratio', 'Drift_rate(Hz/sec)']]

    print("Scaling data...")
    # Using robust scaling due to high kurtosis; robust to outliers
    from sklearn.preprocessing import RobustScaler
    rb_sc = RobustScaler()
    x = rb_sc.fit_transform(x)

    print("Splitting into training and test sets...")
    from sklearn.model_selection import train_test_split
    x_train, x_test, y_train, y_test = train_test_split(x, y, test_size=0.2, random_state=1)

    start_time = time.time()

    print("Training model...")
    from sklearn.linear_model import SGDClassifier
    sgd_class = SGDClassifier(n_jobs = -1, max_iter=10)
    sgd_class.fit(x_train, y_train)
    y_pred = sgd_class.predict(x_test)
    from sklearn.metrics import accuracy_score
    acc_sgd = accuracy_score(y_test, y_pred)

    end_time = time.time()

    print("Saving model and standard scaler...")
    with open("./models/sgd.pkl", 'wb') as f:
        pickle.dump(sgd_class, f)
    with open("./models/rb_sc_sgd.pkl", 'wb') as f:
        pickle.dump(rb_sc, f)

    print("Saving accuracy and training time...")
    with open("./metrics/sgd_acc.json", 'w') as f:
        json.dump({'SGD_accuracy': acc_sgd}, f)
    with open("./metrics/sgd_time.json", 'w') as f:
        json.dump({'SGD_training_time': end_time - start_time}, f)

    print("Accuracy: " + str(acc_sgd*100) + " %")
    print("Training time: " + str(end_time - start_time) + " seconds")


if __name__ == '__main__':
    sgd()
